
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2022-10-13T15:19:53-0600",
 "dirty": true,
 "error": null,
 "full-revisionid": "4e89fd8d6c71cd88e4232bcd8f400e9b18fb5ec0",
 "version": "0.0.9"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
